@@ -72,6 +72,9 @@ class VersionInfoWriter(docutils.writers.Writer, object):
         self.output = visitor.astext()
 
 
+rfc822_person_regex = re.compile(
+        "^(?P<name>[^<]+) <(?P<email>[^>]+)>$")
+
 class ChangeLogEntry:
     """ An individual entry from the ‘ChangeLog’ document. """
 
@@ -392,36 +395,6 @@ def serialise_version_info_from_mapping(version_info):
     return content
 
 
-rfc822_person_regex = re.compile(
-        "^(?P<name>[^<]+) <(?P<email>[^>]+)>$")
-
-ParsedPerson = collections.namedtuple('ParsedPerson', ['name', 'email'])
-
-@lru_cache(maxsize=128)
-def parse_person_field(value):
-    """ Parse a person field into name and email address.
-
-        :param value: The text value specifying a person.
-        :return: A 2-tuple (name, email) for the person's details.
-
-        If the `value` does not match a standard person with email
-        address, the `email` item is ``None``.
-
-        """
-    result = (None, None)
-
-    match = rfc822_person_regex.match(value)
-    if len(value):
-        if match is not None:
-            result = ParsedPerson(
-                    name=match.group('name'),
-                    email=match.group('email'))
-        else:
-            result = ParsedPerson(name=value, email=None)
-
-    return result    
-
-
 @lru_cache(maxsize=128)
 def validate_distutils_release_date_value(distribution, attrib, value):
     """ Validate the ‘release_date’ parameter value.
@@ -469,6 +442,22 @@ def generate_version_info_from_distribution(distribution):
     return result
 
 
+changelog_filename = "ChangeLog"
+
+def get_changelog_path(distribution, filename=changelog_filename):
+    """ Get the changelog file path for the distribution.
+
+        :param distribution: The distutils.dist.Distribution instance.
+        :return: Filesystem path of the changelog document, or ``None``
+            if not discoverable.
+
+        """
+    setup_dirname = os.path.dirname(distribution.script_name)
+    filepath = os.path.join(setup_dirname, filename)
+
+    return filepath
+
+
 def generate_egg_info_metadata(cmd, outfile_name, outfile_path):
     """ Setuptools entry point to generate version info metadata.
 
@@ -481,7 +470,8 @@ def generate_egg_info_metadata(cmd, outfile_name, outfile_path):
         metadata file during build.
 
         """
-    version_info = generate_version_info_from_distribution(cmd.distribution)
+    changelog_path = get_changelog_path(cmd.distribution)
+    version_info = generate_version_info_from_changelog(changelog_path)
     content = serialise_version_info_from_mapping(version_info)
     cmd.write_file("version info", outfile_path, content)
 
